### R code from vignette source 'anoint.Rnw'

###################################################
### code chunk number 1: anoint.Rnw:28-38
###################################################
set.seed(10101)
library(anoint)
data(simsolvd)

simsolvd$event <- 1-simsolvd$censor

obj <- anoint(event~(age+beat+lvef+cardratio+sodium)*trt,
                 family = "binomial", data = simsolvd)

obj


###################################################
### code chunk number 2: anoint.Rnw:49-56
###################################################
simsolvd$noise <- runif(nrow(simsolvd))
  
obj <- anoint(event~(age+beat+lvef+cardratio+sodium+noise)*trt,
                 family = "binomial", data = simsolvd, select="glmnet",
                 keep.vars=c("age","beat"))

obj


###################################################
### code chunk number 3: anoint.Rnw:63-71
###################################################
thescope <- list(lower=event~(age+beat),
                 event~(age+beat+lvef+cardratio+sodium+noise))

obj <- anoint(event~(age+beat+lvef+cardratio+sodium+noise)*trt,
                 family = "binomial", data = simsolvd, select="stepAIC",
                 scope=thescope)

obj


###################################################
### code chunk number 4: anoint.Rnw:80-81 (eval = FALSE)
###################################################
## plot(obj, ylab="treatment effect (odds ratio)")


###################################################
### code chunk number 5: anoint.Rnw:98-107 (eval = FALSE)
###################################################
## simsolvd$age.cat <- factor(simsolvd$age>0)
## simsolvd$beat.cat <- factor(simsolvd$beat>0)
## simsolvd$lvef.cat <- factor(simsolvd$lvef>0)
## simsolvd$sodium.cat <- factor(simsolvd$sodium>0)
##   
## obj <- anoint(event~(age.cat+beat.cat+lvef.cat+cardratio+sodium.cat)*trt,
##                  family = "binomial", data = simsolvd)
## 
## forest(obj)


###################################################
### code chunk number 6: anoint.Rnw:129-135
###################################################
obj <- anoint(event~(age+beat+lvef+cardratio+sodium)*trt,
                 family = "binomial", data = simsolvd)

fit <- anoint.fit(obj, level=.05)

summary(fit)


###################################################
### code chunk number 7: anoint.Rnw:144-147
###################################################
pim.fit <- fits(fit, type = "pim.exact")

pim.fit


###################################################
### code chunk number 8: anoint.Rnw:152-153
###################################################
confint(pim.fit$pim.exact,parm=c("Control","sodium"))


###################################################
### code chunk number 9: anoint.Rnw:162-165
###################################################
obo.fit <- obo(obj) # A list of fits

obo.fit$fit


###################################################
### code chunk number 10: anoint.Rnw:172-176
###################################################
uim.fit <- uim(obj)
summary(uim.fit$fit)
uim.fit$LRT
uim.fit$pvalue


###################################################
### code chunk number 11: anoint.Rnw:181-183
###################################################
pim.fit <- pim(obj, n.boot = 100)
summary(pim.fit)


###################################################
### code chunk number 12: anoint.Rnw:192-194
###################################################
fit <- pim.subsets(event~age+beat+lvef+cardratio+sodium, trt="trt",
                 family = "binomial", data = simsolvd, fwer=0.05)


###################################################
### code chunk number 13: anoint.Rnw:201-202 (eval = FALSE)
###################################################
## forest.subsets(fit)


###################################################
### code chunk number 14: anoint.Rnw:213-215
###################################################
fit <- anoint.subgroups(event~age+beat+lvef+cardratio+sodium, trt="trt",
                 family = "binomial", data = simsolvd, fwer=0.05)


###################################################
### code chunk number 15: anoint.Rnw:219-220
###################################################
forest.subsets(fit, subgroup.title="Subgroups", subgroup=TRUE)


